import { defineNuxtModule, createResolver, addPlugin, installModule, addComponentsDir } from '@nuxt/kit';

const module = defineNuxtModule({
  meta: {
    name: "manolis-ui",
    configKey: "manolisUI"
  },
  // Default configuration options of the Nuxt module
  defaults: {
    css: true
  },
  async setup(_options, _nuxt) {
    const resolver = createResolver(import.meta.url);
    addPlugin(resolver.resolve("./runtime/plugin"));
    await installModule("@nuxtjs/tailwindcss", {
      /**
       * Here, you specify where your config is.
       * By default, the module have a configPath relative
       * to the current path, ie the playground !
       * (or the app using your module)
       */
      cssPath: _options.css ? resolver.resolve("./runtime/assets/css/tailwind.css") : false,
      configPath: resolver.resolve("../tailwind.config")
    });
    await addComponentsDir({
      path: resolver.resolve("./runtime/components"),
      pathPrefix: false,
      prefix: "",
      global: true
    });
    _nuxt.hook("nitro:config", async (nitroConfig) => {
      nitroConfig.publicAssets ||= [];
      nitroConfig.publicAssets.push({
        dir: resolver.resolve("./runtime/assets"),
        // path of assets
        maxAge: 60 * 60 * 24 * 365
        // cache assets for 1 year
      });
    });
  }
});

export { module as default };
