import { onMounted, ref, watch } from "vue";
export const useLocalStorage = (key, initialValue) => {
  const storedValue = ref(null);
  onMounted(() => {
    if (typeof window !== "undefined") {
      const stored = window.localStorage.getItem(key);
      storedValue.value = stored ? JSON.parse(stored) : initialValue;
    }
  });
  watch(storedValue, (newValue) => {
    if (typeof window !== "undefined") {
      window.localStorage.setItem(key, JSON.stringify(newValue));
    }
  });
  return storedValue;
};
